==> core-1.0.2.tgz: package/lib/fields/weekField.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import * as flatpickerNamespace from 'flatpickr';
const flatpickr = flatpickerNamespace.default;
import { Field } from '../field.js';
import * as _weekSelectPlugin from 'flatpickr/dist/plugins/weekSelect/weekSelect.js';
const weekSelectPlugin = _weekSelectPlugin;
export class WeekField extends Field {
    constructor(parent, form, options) {
        super(parent, form, options);
        this.options = {
            id: '',
            type: 'date',
            required: false,
            validation: (value, data, required) => {
                if (required && !value)
                    return 'This field is required';
                return true;
            },
            className: 'form-input',
            enhance: true,
            options: {
                altInput: true,
                plugins: [weekSelectPlugin({})],
            },
        };
        this.initializeOptions(options);
        this.onGui();
        this.initialize();
    }
    initialize() {
        return __awaiter(this, void 0, void 0, function* () {
            this.load();
            this.update();
            this.initFlatpickr();
            this.bindChange();
        });
    }
    getFlatpickr() {
        return this._flatpickr;
    }
    initFlatpickr() {
        if (this.inputElement && this.options.enhance)
            this._flatpickr = flatpickr(this.inputElement, this.options.options || {});
    }
    bindChange() {
        if (this.inputElement)
            this.inputElement.addEventListener('change', (event) => {
                this.change(event);
            });
    }
    createInputElement() {
        this.inputElement = document.createElement('input');
        this.inputElement.setAttribute('id', this.getId());
        this.inputElement.setAttribute('name', this.options.name || this.getId());
        this.inputElement.setAttribute('type', this.options.enhance ? 'text' : 'week');
        this.inputElement.className = this.options.className;
    }
}

==> core-1.0.14.tgz: package/lib/fields/weekField.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import * as flatpickerNamespace from 'flatpickr';
const flatpickr = flatpickerNamespace.default;
import { Field } from '../field.js';
import weekSelectPlugin from 'flatpickr/dist/plugins/weekSelect/weekSelect.js';
export class WeekField extends Field {
    constructor(parent, form, options) {
        super(parent, form, options);
        this.options = {
            id: '',
            type: 'week',
            required: false,
            validation: (value, data, required) => {
                if (required && !value)
                    return 'This field is required';
                return true;
            },
            className: 'form-input',
            enhance: true,
            options: {
                altInput: true,
                dateFormat: "Y-W",
                altFormat: "W, Y",
                plugins: [weekSelectPlugin()],
            },
        };
        this._flatpickr = null;
        this.initializeOptions(options);
        this.onGui();
        this.initialize();
    }
    initialize() {
        return __awaiter(this, void 0, void 0, function* () {
            this.load();
            this.update();
            this.initFlatpickr();
            this.bindChange();
        });
    }
    getFlatpickr() {
        return this._flatpickr;
    }
    initFlatpickr() {
        if (this.inputElement && this.options.enhance)
            this._flatpickr = flatpickr(this.inputElement, this.options.options || {});
    }
    bindChange() {
        if (this.inputElement)
            this.inputElement.addEventListener('change', (event) => {
                this.change(event);
            });
    }
    createInputElement() {
        this.inputElement = document.createElement('input');
        this.inputElement.setAttribute('id', this.getId());
        this.inputElement.setAttribute('name', this.options.name || this.getId());
        this.inputElement.setAttribute('type', this.options.enhance ? 'text' : 'week');
        this.inputElement.className = this.options.className;
        if (this.options.placeholder)
            this.inputElement.setAttribute('placeholder', this.options.placeholder);
    }
}
